@@ -28,6 +28,47 @@ class HardwareType(str, Enum):
     Broadwell = "Broadwell"
     NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
 
+    HAILO8 = "Hailo-8"
+    AMBARELLA = "Ambarella"
+    APPLE_IPHONE_A11 = "Apple iPhone A11"
+    APPLE_IPHONE_A12 = "Apple iPhone A12"
+    APPLE_IPHONE_A14 = "Apple iPhone A14"
+    APPLE_IPHONE_A15 = "Apple iPhone A15"
+    SNAPDRAGON_845 = "Snapdragon 845"
+    SNAPDRAGON_855 = "Snapdragon 855"
+    SNAPDRAGON_885 = "Snapdragon 888"
+    SNAPDRAGON_8_GEN_1 = "Snapdragon 8 Gen 1"
+    EXYNOS_9810 = "Exynos 9810"
+    EXYNOS_9820 = "Exynos 9820"
+    EXYNOS_990 = "Exynos 990"
+    EXYNOS_2200 = "Exynos 2200"
+
+    @property
+    def is_future(self):
+        return self in [
+            HardwareType.HAILO8,
+            HardwareType.AMBARELLA,
+            HardwareType.APPLE_IPHONE_A11,
+            HardwareType.APPLE_IPHONE_A12,
+            HardwareType.APPLE_IPHONE_A14,
+            HardwareType.APPLE_IPHONE_A15,
+            HardwareType.SNAPDRAGON_845,
+            HardwareType.SNAPDRAGON_855,
+            HardwareType.SNAPDRAGON_885,
+            HardwareType.SNAPDRAGON_8_GEN_1,
+            HardwareType.EXYNOS_9810,
+            HardwareType.EXYNOS_9820,
+            HardwareType.EXYNOS_990,
+            HardwareType.EXYNOS_2200,
+        ]
+
+
+class HardwareGroup(str, Enum):
+    CPU = "CPU"
+    GPU = "GPU"
+    COMMERCIAL_EDGE = "Commercial Edge"
+    CONSUMER_EDGE = "Consumer Edge"
+
 
 class HardwareMachineModel(str, Enum):
     K80 = "p2.xlarge"
@@ -35,16 +76,31 @@ class HardwareMachineModel(str, Enum):
     T4 = "g4dn.2xlarge"
     CPU = "c5.4xlarge"
     EPYC = "c5a.2xlarge"
-    NANO = "Jetson Nano"
-    XAVIER = "Jetson Xavier"
-    XAVIER_AGX = "Jetson Xavier AGX"
-    ORIN = "Jetson Orin"
     CASCADE_LAKE = "c5.4xlarge"
     SKYLAKE = "c5n.4xlarge"
     Broadwell = "m4.4xlarge"
-    NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
-    A100_80G = "A100 80GB GCP"
-    A100_40G = "A100 40GB GCP"
+
+    NANO = HardwareType.NANO.value
+    XAVIER = HardwareType.XAVIER.value
+    XAVIER_AGX = HardwareType.XAVIER_AGX.value
+    ORIN = HardwareType.ORIN.value
+    NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
+    A100_80G = HardwareType.A100_80G.value
+    A100_40G = HardwareType.A100_40G.value
+    HAILO8 = HardwareType.HAILO8.value
+    AMBARELLA = HardwareType.AMBARELLA.value
+    APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
+    APPLE_IPHONE_A12 = HardwareType.APPLE_IPHONE_A12.value
+    APPLE_IPHONE_A14 = HardwareType.APPLE_IPHONE_A14.value
+    APPLE_IPHONE_A15 = HardwareType.APPLE_IPHONE_A15.value
+    SNAPDRAGON_845 = HardwareType.SNAPDRAGON_845.value
+    SNAPDRAGON_855 = HardwareType.SNAPDRAGON_855.value
+    SNAPDRAGON_885 = HardwareType.SNAPDRAGON_885.value
+    SNAPDRAGON_8_GEN_1 = HardwareType.SNAPDRAGON_8_GEN_1.value
+    EXYNOS_9810 = HardwareType.EXYNOS_9810.value
+    EXYNOS_9820 = HardwareType.EXYNOS_9820.value
+    EXYNOS_990 = HardwareType.EXYNOS_990.value
+    EXYNOS_2200 = HardwareType.EXYNOS_2200.value
 
 
 class InferenceHardware(str, Enum):
@@ -241,3 +297,38 @@ class MapHardwareTypeToImageDistribution(str, Enum):
     XAVIER = HardwareImageDistribution.J46.value
     XAVIER_AGX = HardwareImageDistribution.J46.value
     ORIN = HardwareImageDistribution.J50.value
+
+
+class MapHardwareTypeToGroup(str, Enum):
+    K80 = HardwareGroup.GPU.value
+    V100 = HardwareGroup.GPU.value
+    T4 = HardwareGroup.GPU.value
+    A100_80G = HardwareGroup.GPU.value
+    A100_40G = HardwareGroup.GPU.value
+
+    XAVIER = HardwareGroup.COMMERCIAL_EDGE.value
+    NANO = HardwareGroup.COMMERCIAL_EDGE.value
+    XAVIER_AGX = HardwareGroup.COMMERCIAL_EDGE.value
+    ORIN = HardwareGroup.COMMERCIAL_EDGE.value
+    NUC_TIGER_LAKE = HardwareGroup.COMMERCIAL_EDGE.value
+    AMBARELLA = HardwareGroup.COMMERCIAL_EDGE.value
+    HAILO8 = HardwareGroup.COMMERCIAL_EDGE.value
+
+    CPU = HardwareGroup.CPU.value
+    EPYC = HardwareGroup.CPU.value
+    CASCADE_LAKE = HardwareGroup.CPU.value
+    SKYLAKE = HardwareGroup.CPU.value
+    Broadwell = HardwareGroup.CPU.value
+
+    APPLE_IPHONE_A11 = HardwareGroup.CONSUMER_EDGE.value
+    APPLE_IPHONE_A12 = HardwareGroup.CONSUMER_EDGE.value
+    APPLE_IPHONE_A14 = HardwareGroup.CONSUMER_EDGE.value
+    APPLE_IPHONE_A15 = HardwareGroup.CONSUMER_EDGE.value
+    SNAPDRAGON_845 = HardwareGroup.CONSUMER_EDGE.value
+    SNAPDRAGON_855 = HardwareGroup.CONSUMER_EDGE.value
+    SNAPDRAGON_885 = HardwareGroup.CONSUMER_EDGE.value
+    SNAPDRAGON_8_GEN_1 = HardwareGroup.CONSUMER_EDGE.value
+    EXYNOS_9810 = HardwareGroup.CONSUMER_EDGE.value
+    EXYNOS_9820 = HardwareGroup.CONSUMER_EDGE.value
+    EXYNOS_990 = HardwareGroup.CONSUMER_EDGE.value
+    EXYNOS_2200 = HardwareGroup.CONSUMER_EDGE.value
