@@ -16,6 +16,8 @@ from deci_common.data_types.enum.hardware_enums import (
     HardwareImageRepository,
     MapHardwareTypeToImageDistribution,
     MapHardwareTypeToImageRepository,
+    HardwareGroup,
+    MapHardwareTypeToGroup,
 )
 
 
@@ -26,8 +28,10 @@ class HardwareReturnSchema(Schema):
     """
 
     name: HardwareType
-    vendor: HardwareVendor
-    machine: HardwareMachineModel = None
+    vendor: Optional[HardwareVendor] = None
+    machine: Optional[HardwareMachineModel] = None
+    group: Optional[HardwareGroup] = None
+    future: bool = False
 
 
 class Hardware(Schema):
@@ -73,6 +77,8 @@ def get_hardware_return_schema(hw_name: HardwareType) -> HardwareReturnSchema:
         hw_name = HardwareType(hw_name)
     return HardwareReturnSchema(
         name=hw_name,
-        vendor=MapHardwareTypeToVendor[hw_name.name].value,
+        vendor=MapHardwareTypeToVendor[hw_name.name].value if hasattr(MapHardwareTypeToVendor, hw_name.name) else None,
         machine=HardwareMachineModel[hw_name.name].value,
+        group=MapHardwareTypeToGroup[hw_name.name].value,
+        future=hw_name.is_future,
     )
